#pragma once
/*
Parsec QR Library examples for PNR QX29 family of a proximity readers.
Author Dmitry Bogdan <dbogdan@mdo.ru> (c) 2021, 2022.

For support please contact: <support@parsec.ru>
*/

#include <stdint.h>

#include "qr_constants.h"
#include "qr_usertypes.h"

#ifdef __cplusplus
extern "C" {
#endif

#if defined(WINDOWS)
#	ifdef libpnrqx29_EXPORTS
#		define libpnrqx29_EXPORTS  __declspec(dllexport)
#	else
#		define libpnrqx29_EXPORTS  __declspec(dllimport)
#	endif
#else
#	define libpnrqx29_EXPORTS
#endif

/* creates library context with a new private key */
libpnrqx29_EXPORTS struct qr_context *qr_new_ctx(const qr_AesKey_t *key);

/* creates library context with a default key */
libpnrqx29_EXPORTS struct qr_context *qr_new_default_ctx();

/* deletes library context */
libpnrqx29_EXPORTS void qr_delete_ctx(struct qr_context *ctx);

/* current to default key */
libpnrqx29_EXPORTS int qr_GenSetDefaultAesKey(struct qr_context *ctx, uint8_t *destination);

/* set new key */
libpnrqx29_EXPORTS int qr_GenSetAesKey(struct qr_context *ctx, const qr_AesKey_t *new_key, uint8_t *destination);

/* 4 octets code */
libpnrqx29_EXPORTS int qr_GenId4(struct qr_context *ctx, const uint32_t id, uint8_t *destination);

/* 7 octets code */
libpnrqx29_EXPORTS int qr_GenId7(struct qr_context *ctx, const uint64_t id, uint8_t *destination);

/* config code */
libpnrqx29_EXPORTS int qr_GenLightConf(struct qr_context *ctx, uint8_t light_mode, uint16_t light_threshold, uint8_t target_mode, uint8_t *destination);

/* access code */
libpnrqx29_EXPORTS int qr_GenAccess(struct qr_context *ctx, const uint32_t id, qr_UserAccess_t *access, uint8_t *destination);

#ifdef __cplusplus
}
#endif