#include <string.h>

#include "example_main.h"

int example_genaccess()
{
    int result = QR_RESULT_ERR;

    uint8_t encrypted_result[QR_DATA_STRUCT_LEN_ASCII + 1];
    encrypted_result[QR_DATA_STRUCT_LEN_ASCII] = 0;

    qr_UserAccess_t access;

    // ISO 8601 Date and time from
    // "2005-08-09T18:31:42" + trailing zero byte
    // Please convert one digit number to two digits:
    // 0 seconds, 5 minuts or 8 hours to "00" seconds, "05" minutes and "08" respectively
    // or 2nd month or 8th day to "02" month and "08" day
    // Please do not use multibyte or UTF-8 characters and terminate string with zero
    strncpy(access.DateTimeFrom, "2022-02-14T09:00:42", USER_ACCESS_DATETIME_LEN);
    strncpy(access.DateTimeTo, "2022-05-24T00:00:00", USER_ACCESS_DATETIME_LEN);

    // Interval during full day
    // ISO 8601 Extended format w/o decial fraction of the second
    // "18:31:42" + trailing zero byte
    // Please do not use single digits values as well (see comment above for DateTime values)
    // Fill with all zeroes if you have 1-day interval limited with
    // DateTimeFrom and DateTimeTo (you have 1-day event).
    // Please do not use multibyte or UTF-8 characters and terminate string with zero
    strncpy(access.TimeStart, "14:33:00", USER_ACCES_TIME_LEN);
    strncpy(access.TimeEnd, "15:20:42", USER_ACCES_TIME_LEN);

    // List of four allowed Rooms (or Areas) for a visitor
    access.Area[0] = 42;
    // Please set all to zero if unused
    access.Area[1] = 0;
    access.Area[2] = 0;
    access.Area[3] = 0;

    struct qr_context *ctx = qr_new_default_ctx();

    if (ctx != NULL)
    {
        result = qr_GenAccess(ctx, 0x12345678, &access, encrypted_result);
        qr_delete_ctx(ctx);
    }

    if (result == QR_RESULT_OK)
    {
        printf("encrypted with default key, id4: 0x12345678 with access field Area: 0:%u 1:%u 2:%u 3:%u\n result: %s\n",
               access.Area[0], access.Area[1], access.Area[2], access.Area[3],
               encrypted_result);
    }
    else if (result == QR_RESULT_ERR_INVALID_ARGS)
    {
        printf("failed to encrypt id4 with useraccess, invalid arguments, check your date or time strings\n");
    }
    else
    {
        // unreachable, actually
        printf("failed to encrypt id4 with useraccess with unknown result %d\n", result);
    }

    return result;
}